summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:11:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:11:36 -0600
commit96e30b1181f5c0679f704b33fd230bb088db2147 (patch)
treebda24075f3bced33a20a101333b98e119a4257fc
parent4d6cade4fdcec31669bcc95f6cbb0dee4d2f09d9 (diff)
downloadkonversation-96e30b11.tar.gz
konversation-96e30b11.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
-rw-r--r--konversation/src/autoreplace_preferences.cpp4
-rw-r--r--konversation/src/config/konversation.kcfg4
-rw-r--r--konversation/src/config/preferences.cpp4
-rw-r--r--konversation/src/dccchat.h4
-rw-r--r--konversation/src/dcccommon.cpp10
-rw-r--r--konversation/src/dcccommon.h6
-rw-r--r--konversation/src/dcctransfer.cpp8
-rw-r--r--konversation/src/dcctransfer.h16
-rw-r--r--konversation/src/dcctransferpanelitem.cpp6
-rw-r--r--konversation/src/dcctransferpanelitem.h2
-rw-r--r--konversation/src/dcctransferrecv.cpp52
-rw-r--r--konversation/src/dcctransferrecv.h30
-rw-r--r--konversation/src/dcctransfersend.cpp22
-rw-r--r--konversation/src/dcctransfersend.h6
-rw-r--r--konversation/src/highlight_preferences.cpp2
-rw-r--r--konversation/src/ircview.cpp2
-rw-r--r--konversation/src/konversationapplication.cpp4
-rw-r--r--konversation/src/konviconfigdialog.cpp32
-rw-r--r--konversation/src/konviconfigdialog.h24
-rw-r--r--konversation/src/konvisettingsdialog.cpp4
-rw-r--r--konversation/src/konvisettingspage.h2
-rw-r--r--konversation/src/logfilereader.cpp6
-rw-r--r--konversation/src/logfilereader.h2
-rw-r--r--konversation/src/osd_preferences.cpp2
-rw-r--r--konversation/src/outputfilter.cpp6
-rw-r--r--konversation/src/outputfilter.h2
-rw-r--r--konversation/src/quickbuttons_preferences.cpp4
-rw-r--r--konversation/src/server.cpp18
-rw-r--r--konversation/src/server.h2
-rw-r--r--konversation/src/serverlistdialog.cpp4
-rw-r--r--konversation/src/theme_preferences.cpp16
-rw-r--r--konversation/src/theme_preferences.h2
-rw-r--r--konversation/src/warnings_preferences.cpp4
33 files changed, 156 insertions, 156 deletions
diff --git a/konversation/src/autoreplace_preferences.cpp b/konversation/src/autoreplace_preferences.cpp
index b96bf67..2f785bc 100644
--- a/konversation/src/autoreplace_preferences.cpp
+++ b/konversation/src/autoreplace_preferences.cpp
@@ -129,7 +129,7 @@ void Autoreplace_Config::setAutoreplaceListView(const TQStringList &autoreplaceL
void Autoreplace_Config::saveSettings()
{
// get configuration object
- KConfig* config=kapp->config();
+ TDEConfig* config=kapp->config();
// delete all patterns
config->deleteGroup("Autoreplace List");
@@ -149,7 +149,7 @@ void Autoreplace_Config::saveSettings()
config->writeEntry(TQString("Autoreplace%1").arg(index),newList[index]+'#');
} // for
}
- // if there were no entries at all, write a dummy entry to prevent KConfigXT from "optimizing"
+ // if there were no entries at all, write a dummy entry to prevent TDEConfigXT from "optimizing"
// the group out, which would in turn make konvi restore the default entries
else
config->writeEntry("Empty List",TQString());
diff --git a/konversation/src/config/konversation.kcfg b/konversation/src/config/konversation.kcfg
index dc2894e..61f171a 100644
--- a/konversation/src/config/konversation.kcfg
+++ b/konversation/src/config/konversation.kcfg
@@ -95,7 +95,7 @@
<label></label>
<whatsthis></whatsthis>
</entry>
-<!-- quick buttons are handled outside of KConfigXT for now (Eisfuchs)
+<!-- quick buttons are handled outside of TDEConfigXT for now (Eisfuchs)
<entry key="QuickButtons" type="StringList" name="ButtonList">
<default code="true">(QStringList() &lt;&lt; "Op,/OP %u%n"&lt;&lt;"DeOp,/DEOP %u%n"&lt;&lt;"WhoIs,/WHOIS %s,%%u%n"&lt;&lt;"Version,/CTCP %s,%%u VERSION%n"&lt;&lt;"Kick,/KICK %u%n"&lt;&lt;"Kick,/KICK %u%n"&lt;&lt;"Ban,/BAN %u%n"&lt;&lt;"Part,/PART %c Leaving...%n"&lt;&lt;"Quit,/QUIT Leaving...%n")</default>
</entry> -->
@@ -396,7 +396,7 @@
</entry>
</group>
<group name="Sort Nicknames">
-<!-- done outside of KConfigXT (Eisfuchs)
+<!-- done outside of TDEConfigXT (Eisfuchs)
<entry key="AdminValue" type="Int">
<default>1</default>
<label></label>
diff --git a/konversation/src/config/preferences.cpp b/konversation/src/config/preferences.cpp
index 19839fa..8a2a942 100644
--- a/konversation/src/config/preferences.cpp
+++ b/konversation/src/config/preferences.cpp
@@ -526,7 +526,7 @@ void Preferences::setAutoUserhost(bool state)
bool Preferences::dialogFlag(const TQString& flagName)
{
- KConfig* config=TDEApplication::kApplication()->config();
+ TDEConfig* config=TDEApplication::kApplication()->config();
config->setGroup("Notification self()->Messages");
@@ -538,7 +538,7 @@ bool Preferences::dialogFlag(const TQString& flagName)
void Preferences::setDialogFlag(const TQString& flagName,bool state)
{
- KConfig* config=TDEApplication::kApplication()->config();
+ TDEConfig* config=TDEApplication::kApplication()->config();
config->setGroup("Notification self()->Messages");
diff --git a/konversation/src/dccchat.h b/konversation/src/dccchat.h
index 1259cdf..855e75a 100644
--- a/konversation/src/dccchat.h
+++ b/konversation/src/dccchat.h
@@ -24,7 +24,7 @@ class Server;
namespace KNetwork
{
- class KServerSocket;
+ class TDEServerSocket;
class KStreamSocket;
}
@@ -94,7 +94,7 @@ class DccChat : public ChatWindow
Konversation::TopicLabel* m_sourceLine;
IRCInput* m_dccChatInput;
KNetwork::KStreamSocket* m_dccSocket;
- KNetwork::KServerSocket* m_listenSocket;
+ KNetwork::TDEServerSocket* m_listenSocket;
TQString m_encoding;
diff --git a/konversation/src/dcccommon.cpp b/konversation/src/dcccommon.cpp
index 7af67c2..4bf2ef0 100644
--- a/konversation/src/dcccommon.cpp
+++ b/konversation/src/dcccommon.cpp
@@ -69,9 +69,9 @@ TQString DccCommon::getOwnIp( Server* server )
return ownIp;
}
-KNetwork::KServerSocket* DccCommon::createServerSocketAndListen( TQObject* parent, TQString* failedReason, int minPort, int maxPort )
+KNetwork::TDEServerSocket* DccCommon::createServerSocketAndListen( TQObject* parent, TQString* failedReason, int minPort, int maxPort )
{
- KNetwork::KServerSocket* socket = new KNetwork::KServerSocket( parent );
+ KNetwork::TDEServerSocket* socket = new KNetwork::TDEServerSocket( parent );
socket->setFamily( KNetwork::KResolver::InetFamily );
if ( minPort > 0 && maxPort >= minPort ) // ports are configured manually
@@ -82,7 +82,7 @@ KNetwork::KServerSocket* DccCommon::createServerSocketAndListen( TQObject* paren
{
socket->setAddress( TQString::number( port ) );
bool success = socket->listen();
- if ( ( found = ( success && socket->error() == KNetwork::KSocketBase::NoError ) ) )
+ if ( ( found = ( success && socket->error() == KNetwork::TDESocketBase::NoError ) ) )
break;
socket->close();
}
@@ -110,9 +110,9 @@ KNetwork::KServerSocket* DccCommon::createServerSocketAndListen( TQObject* paren
return socket;
}
-int DccCommon::getServerSocketPort( KNetwork::KServerSocket* serverSocket )
+int DccCommon::getServerSocketPort( KNetwork::TDEServerSocket* serverSocket )
{
- KNetwork::KSocketAddress ipAddr = serverSocket->localAddress();
+ KNetwork::TDESocketAddress ipAddr = serverSocket->localAddress();
const struct sockaddr_in* socketAddress = (sockaddr_in*)ipAddr.address();
return ntohs( socketAddress->sin_port );
}
diff --git a/konversation/src/dcccommon.h b/konversation/src/dcccommon.h
index b556524..b70fa62 100644
--- a/konversation/src/dcccommon.h
+++ b/konversation/src/dcccommon.h
@@ -18,7 +18,7 @@ class TQObject;
namespace KNetwork
{
- class KServerSocket;
+ class TDEServerSocket;
}
class Server;
@@ -36,10 +36,10 @@ class DccCommon
static TQString getOwnIp( Server* server = 0 );
// creates an instance of KNetwork::ServerSocket following the DCC settings
- static KNetwork::KServerSocket* createServerSocketAndListen( TQObject* parent = 0, TQString* failedReason = 0, int minPort = 0, int maxPort = 0 );
+ static KNetwork::TDEServerSocket* createServerSocketAndListen( TQObject* parent = 0, TQString* failedReason = 0, int minPort = 0, int maxPort = 0 );
// returns the port number from a server socket
- static int getServerSocketPort( KNetwork::KServerSocket* serverSocket );
+ static int getServerSocketPort( KNetwork::TDEServerSocket* serverSocket );
private:
DccCommon();
diff --git a/konversation/src/dcctransfer.cpp b/konversation/src/dcctransfer.cpp
index c12147f..4873b79 100644
--- a/konversation/src/dcctransfer.cpp
+++ b/konversation/src/dcctransfer.cpp
@@ -157,7 +157,7 @@ void DccTransfer::updateTransferMeters()
// remove too old data
TQValueList<int>::iterator itTime = m_transferLogTime.begin();
- TQValueList<KIO::fileoffset_t>::iterator itPos = m_transferLogPosition.begin();
+ TQValueList<TDEIO::fileoffset_t>::iterator itPos = m_transferLogPosition.begin();
while ( itTime != m_transferLogTime.end() && ( m_transferLogTime.last() - (*itTime) > timeToCalc * 1000 ) )
{
itTime = m_transferLogTime.remove( itTime );
@@ -290,17 +290,17 @@ TQString DccTransfer::getFileName() const
return m_fileName;
}
-KIO::filesize_t DccTransfer::getFileSize() const
+TDEIO::filesize_t DccTransfer::getFileSize() const
{
return m_fileSize;
}
-KIO::fileoffset_t DccTransfer::getTransferringPosition() const
+TDEIO::fileoffset_t DccTransfer::getTransferringPosition() const
{
return m_transferringPosition;
}
-KIO::fileoffset_t DccTransfer::getTransferStartPosition() const
+TDEIO::fileoffset_t DccTransfer::getTransferStartPosition() const
{
return m_transferStartPosition;
}
diff --git a/konversation/src/dcctransfer.h b/konversation/src/dcctransfer.h
index f4b03a9..3da2a55 100644
--- a/konversation/src/dcctransfer.h
+++ b/konversation/src/dcctransfer.h
@@ -76,9 +76,9 @@ class DccTransfer : public TQObject
TQString getPartnerIp() const;
TQString getPartnerPort() const;
TQString getFileName() const;
- KIO::filesize_t getFileSize() const;
- KIO::fileoffset_t getTransferringPosition() const;
- KIO::fileoffset_t getTransferStartPosition() const;
+ TDEIO::filesize_t getFileSize() const;
+ TDEIO::fileoffset_t getTransferringPosition() const;
+ TDEIO::fileoffset_t getTransferStartPosition() const;
KURL getFileURL() const;
bool isResumed() const;
bool isReverse() const;
@@ -127,12 +127,12 @@ class DccTransfer : public TQObject
bool m_resumed;
bool m_reverse;
TQString m_reverseToken;
- KIO::fileoffset_t m_transferringPosition;
- KIO::fileoffset_t m_transferStartPosition;
+ TDEIO::fileoffset_t m_transferringPosition;
+ TDEIO::fileoffset_t m_transferStartPosition;
/*
TQValueList<TQDateTime> m_transferTimeLog; // write per packet to calc CPS
- TQValueList<KIO::fileoffset_t> m_transferPositionLog; // write per packet to calc CPS
+ TQValueList<TDEIO::fileoffset_t> m_transferPositionLog; // write per packet to calc CPS
*/
// we'll communicate with the partner via this server
@@ -154,7 +154,7 @@ class DccTransfer : public TQObject
TQString m_fileName;
/** The file size of the complete file sending/recieving. */
- KIO::filesize_t m_fileSize;
+ TDEIO::filesize_t m_fileSize;
/**
* If we are sending a file, this is the url of the file we are sending.
@@ -177,7 +177,7 @@ class DccTransfer : public TQObject
TQTimer m_loggerTimer;
TQTime m_loggerBaseTime; // for calculating CPS
TQValueList<int> m_transferLogTime;
- TQValueList<KIO::fileoffset_t> m_transferLogPosition;
+ TQValueList<TDEIO::fileoffset_t> m_transferLogPosition;
transferspeed_t m_averageSpeed;
transferspeed_t m_currentSpeed;
diff --git a/konversation/src/dcctransferpanelitem.cpp b/konversation/src/dcctransferpanelitem.cpp
index f8fc1d0..9e24fb2 100644
--- a/konversation/src/dcctransferpanelitem.cpp
+++ b/konversation/src/dcctransferpanelitem.cpp
@@ -333,7 +333,7 @@ TQString DccTransferPanelItem::getStatusText() const
TQString DccTransferPanelItem::getFileSizePrettyText() const
{
- return KIO::convertSize( m_transfer->getFileSize() );
+ return TDEIO::convertSize( m_transfer->getFileSize() );
}
TQString DccTransferPanelItem::getPositionPrettyText( bool detailed ) const
@@ -342,7 +342,7 @@ TQString DccTransferPanelItem::getPositionPrettyText( bool detailed ) const
return TDEGlobal::locale()->formatNumber( m_transfer->getTransferringPosition(), 0 ) + " / " +
TDEGlobal::locale()->formatNumber( m_transfer->getFileSize(), 0 );
else
- return KIO::convertSize( m_transfer->getTransferringPosition() ) + " / " + KIO::convertSize( m_transfer->getFileSize() );
+ return TDEIO::convertSize( m_transfer->getTransferringPosition() ) + " / " + TDEIO::convertSize( m_transfer->getFileSize() );
}
TQString DccTransferPanelItem::getTimeLeftPrettyText() const
@@ -384,7 +384,7 @@ TQString DccTransferPanelItem::getSpeedPrettyText( transferspeed_t speed )
else if ( speed == DccTransfer::NotInTransfer )
return TQString();
else
- return i18n("%1/sec").arg( KIO::convertSize( (KIO::fileoffset_t)speed ) );
+ return i18n("%1/sec").arg( TDEIO::convertSize( (TDEIO::fileoffset_t)speed ) );
}
TQString DccTransferPanelItem::secToHMS( long sec )
diff --git a/konversation/src/dcctransferpanelitem.h b/konversation/src/dcctransferpanelitem.h
index af2601c..7ca27ad 100644
--- a/konversation/src/dcctransferpanelitem.h
+++ b/konversation/src/dcctransferpanelitem.h
@@ -30,7 +30,7 @@ class TQTimer;
class KProgress;
-namespace KIO
+namespace TDEIO
{
class Job;
}
diff --git a/konversation/src/dcctransferrecv.cpp b/konversation/src/dcctransferrecv.cpp
index ef2cc0e..8b83de0 100644
--- a/konversation/src/dcctransferrecv.cpp
+++ b/konversation/src/dcctransferrecv.cpp
@@ -256,7 +256,7 @@ void DccTransferRecv::start() // public slot
kdDebug() << "DccTransferRecv::start() [END]" << endl;
}
-void DccTransferRecv::prepareLocalKio( bool overwrite, bool resume, KIO::fileoffset_t startPosition /* = 0 */ )
+void DccTransferRecv::prepareLocalKio( bool overwrite, bool resume, TDEIO::fileoffset_t startPosition /* = 0 */ )
{
kdDebug() << "DccTransferRecv::prepareLocalKio()" << endl
<< "DccTransferRecv::prepareLocalKio(): URL: " << m_fileURL << endl
@@ -276,21 +276,21 @@ void DccTransferRecv::prepareLocalKio( bool overwrite, bool resume, KIO::fileoff
return;
}
- KIO::TransferJob* transferJob = KIO::put( m_fileURL, -1, overwrite, m_resumed, false );
+ TDEIO::TransferJob* transferJob = TDEIO::put( m_fileURL, -1, overwrite, m_resumed, false );
if ( !transferJob )
{
- kdDebug() << "DccTransferRecv::prepareLocalKio(): KIO::put() returned NULL. what happened?" << endl;
+ kdDebug() << "DccTransferRecv::prepareLocalKio(): TDEIO::put() returned NULL. what happened?" << endl;
failed( i18n( "Could not create a KIO instance" ) );
return;
}
- connect( transferJob, TQT_SIGNAL( canResume( KIO::Job*, KIO::filesize_t ) ), this, TQT_SLOT( slotLocalCanResume( KIO::Job*, KIO::filesize_t ) ) );
- connect( transferJob, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( slotLocalGotResult( KIO::Job* ) ) );
- connect( transferJob, TQT_SIGNAL( dataReq( KIO::Job*, TQByteArray& ) ), this, TQT_SLOT( slotLocalReady( KIO::Job* ) ) );
+ connect( transferJob, TQT_SIGNAL( canResume( TDEIO::Job*, TDEIO::filesize_t ) ), this, TQT_SLOT( slotLocalCanResume( TDEIO::Job*, TDEIO::filesize_t ) ) );
+ connect( transferJob, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( slotLocalGotResult( TDEIO::Job* ) ) );
+ connect( transferJob, TQT_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ), this, TQT_SLOT( slotLocalReady( TDEIO::Job* ) ) );
}
-void DccTransferRecv::askAndPrepareLocalKio( const TQString& message, int enabledActions, DccResumeDialog::ReceiveAction defaultAction, KIO::fileoffset_t startPosition )
+void DccTransferRecv::askAndPrepareLocalKio( const TQString& message, int enabledActions, DccResumeDialog::ReceiveAction defaultAction, TDEIO::fileoffset_t startPosition )
{
switch ( DccResumeDialog::ask( this, message, enabledActions, defaultAction ) )
{
@@ -329,21 +329,21 @@ bool DccTransferRecv::createDirs( const KURL& dirURL ) const
TQStringList::ConstIterator it;
for ( it=dirList.begin() ; it!=dirList.end() ; ++it )
- if ( !KIO::NetAccess::exists( *it, true, NULL ) )
- if ( !KIO::NetAccess::mkdir( *it, NULL, -1 ) )
+ if ( !TDEIO::NetAccess::exists( *it, true, NULL ) )
+ if ( !TDEIO::NetAccess::mkdir( *it, NULL, -1 ) )
return false;
return true;
}
-void DccTransferRecv::slotLocalCanResume( KIO::Job* job, KIO::filesize_t size )
+void DccTransferRecv::slotLocalCanResume( TDEIO::Job* job, TDEIO::filesize_t size )
{
kdDebug() << "DccTransferRecv::slotLocalCanResume() [BEGIN]" << endl
<< "DccTransferRecv::slotLocalCanResume(): size: " << TQString::number( size ) << endl;
if ( size != 0 )
{
- KIO::TransferJob* transferJob = static_cast<KIO::TransferJob*>( job );
+ TDEIO::TransferJob* transferJob = static_cast<TDEIO::TransferJob*>( job );
disconnect( transferJob, 0, 0, 0 );
transferJob->kill();
@@ -376,11 +376,11 @@ void DccTransferRecv::slotLocalCanResume( KIO::Job* job, KIO::filesize_t size )
kdDebug() << "DccTransferRecv::slotLocalCanResume() [END]" << endl;
}
-void DccTransferRecv::slotLocalGotResult( KIO::Job* job )
+void DccTransferRecv::slotLocalGotResult( TDEIO::Job* job )
{
kdDebug() << "DccTransferRecv::slotLocalGotResult() [BEGIN]" << endl;
- KIO::TransferJob* transferJob = static_cast<KIO::TransferJob*>( job );
+ TDEIO::TransferJob* transferJob = static_cast<TDEIO::TransferJob*>( job );
disconnect( transferJob, 0, 0, 0 );
switch ( transferJob->error() )
@@ -389,7 +389,7 @@ void DccTransferRecv::slotLocalGotResult( KIO::Job* job )
kdDebug() << "DccTransferRecv::slotLocalGotResult(): job->error() returned 0." << endl
<< "DccTransferRecv::slotLocalGotResult(): Why was I called in spite of no error?" << endl;
break;
- case KIO::ERR_FILE_ALREADY_EXIST:
+ case TDEIO::ERR_FILE_ALREADY_EXIST:
askAndPrepareLocalKio( i18n( "<b>The file already exists.</b><br>"
"%1<br>" )
.arg( m_fileURL.prettyURL() ),
@@ -409,11 +409,11 @@ void DccTransferRecv::slotLocalGotResult( KIO::Job* job )
kdDebug() << "DccTransferRecv::slotLocalGotResult() [END]" << endl;
}
-void DccTransferRecv::slotLocalReady( KIO::Job* job )
+void DccTransferRecv::slotLocalReady( TDEIO::Job* job )
{
kdDebug() << "DccTransferRecv::slotLocalReady()" << endl;
- KIO::TransferJob* transferJob = static_cast<KIO::TransferJob*>( job );
+ TDEIO::TransferJob* transferJob = static_cast<TDEIO::TransferJob*>( job );
disconnect( transferJob, 0, 0, 0 ); // WriteCacheHandler will control the job after this
@@ -590,8 +590,8 @@ void DccTransferRecv::startReceiving()
// slot
void DccTransferRecv::connectionFailed( int errorCode )
{
- kdDebug() << "DccTransferRecv::connectionFailed(): code = " << errorCode << ", string = " << m_recvSocket->KSocketBase::errorString() << endl;
- failed( i18n( "Connection failure: %1" ).arg( m_recvSocket->KSocketBase::errorString() ) );
+ kdDebug() << "DccTransferRecv::connectionFailed(): code = " << errorCode << ", string = " << m_recvSocket->TDESocketBase::errorString() << endl;
+ failed( i18n( "Connection failure: %1" ).arg( m_recvSocket->TDESocketBase::errorString() ) );
}
void DccTransferRecv::readData() // slot
@@ -611,11 +611,11 @@ void DccTransferRecv::readData() // slot
void DccTransferRecv::sendAck() // slot
{
//kdDebug() << "sendAck()" << endl;
- KIO::fileoffset_t pos = intel( m_transferringPosition );
+ TDEIO::fileoffset_t pos = intel( m_transferringPosition );
m_recvSocket->enableWrite( false );
m_recvSocket->writeBlock( (char*)&pos, 4 );
- if ( m_transferringPosition == (KIO::fileoffset_t)m_fileSize )
+ if ( m_transferringPosition == (TDEIO::fileoffset_t)m_fileSize )
{
kdDebug() << "DccTransferRecv::sendAck(): Sent final ACK." << endl;
m_recvSocket->enableRead( false );
@@ -623,7 +623,7 @@ void DccTransferRecv::sendAck() // slot
finishTransferLogger();
m_writeCacheHandler->close(); // WriteCacheHandler will send the signal done()
}
- else if ( m_transferringPosition > (KIO::fileoffset_t)m_fileSize )
+ else if ( m_transferringPosition > (TDEIO::fileoffset_t)m_fileSize )
{
kdDebug() << "DccTransferRecv::sendAck(): the remote host sent larger data than expected: " << TQString::number( m_transferringPosition ) << endl;
failed( i18n( "Transferring error" ) );
@@ -676,15 +676,15 @@ void DccTransferRecv::slotSocketClosed()
// WriteCacheHandler
-DccTransferRecvWriteCacheHandler::DccTransferRecvWriteCacheHandler( KIO::TransferJob* transferJob )
+DccTransferRecvWriteCacheHandler::DccTransferRecvWriteCacheHandler( TDEIO::TransferJob* transferJob )
: m_transferJob( transferJob )
{
m_writeReady = true;
m_cacheStream = 0;
connect( this, TQT_SIGNAL( dataFinished() ), m_transferJob, TQT_SLOT( slotFinished() ) );
- connect( m_transferJob, TQT_SIGNAL( dataReq( KIO::Job*, TQByteArray& ) ), this, TQT_SLOT( slotKIODataReq( KIO::Job*, TQByteArray& ) ) );
- connect( m_transferJob, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( slotKIOResult( KIO::Job* ) ) );
+ connect( m_transferJob, TQT_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ), this, TQT_SLOT( slotKIODataReq( TDEIO::Job*, TQByteArray& ) ) );
+ connect( m_transferJob, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( slotKIOResult( TDEIO::Job* ) ) );
m_transferJob->setAsyncDataEnabled( m_writeAsyncMode = true );
}
@@ -755,7 +755,7 @@ void DccTransferRecvWriteCacheHandler::closeNow() // public
m_cacheStream = 0;
}
-void DccTransferRecvWriteCacheHandler::slotKIODataReq( KIO::Job*, TQByteArray& data )
+void DccTransferRecvWriteCacheHandler::slotKIODataReq( TDEIO::Job*, TQByteArray& data )
{
// We are in writeAsyncMode if there is more data to be read in from dcc
if ( m_writeAsyncMode )
@@ -781,7 +781,7 @@ void DccTransferRecvWriteCacheHandler::slotKIODataReq( KIO::Job*, TQByteArray& d
}
}
-void DccTransferRecvWriteCacheHandler::slotKIOResult( KIO::Job* job )
+void DccTransferRecvWriteCacheHandler::slotKIOResult( TDEIO::Job* job )
{
Q_ASSERT( m_transferJob );
diff --git a/konversation/src/dcctransfersend.h b/konversation/src/dcctransfersend.h
index e4f50f0..9df25ce 100644
--- a/konversation/src/dcctransfersend.h
+++ b/konversation/src/dcctransfersend.h
@@ -26,7 +26,7 @@ class TQTimer;
namespace KNetwork
{
- class KServerSocket;
+ class TDEServerSocket;
class KStreamSocket;
}
@@ -47,7 +47,7 @@ class DccTransferSend : public DccTransfer
// FIXME: this setting should be an optional one or be removed: make DccTransferSend itself read the configuration
void setOwnIp( const TQString& ownIp );
// OPTIONAL
- void setFileSize( KIO::filesize_t fileSize );
+ void setFileSize( TDEIO::filesize_t fileSize );
// OPTIONAL
void setReverse( bool reverse );
@@ -89,7 +89,7 @@ class DccTransferSend : public DccTransfer
*/
TQString m_tmpFile;
- KNetwork::KServerSocket* m_serverSocket;
+ KNetwork::TDEServerSocket* m_serverSocket;
KNetwork::KStreamSocket* m_sendSocket;
bool m_fastSend;
diff --git a/konversation/src/highlight_preferences.cpp b/konversation/src/highlight_preferences.cpp
index aeeeae1..c8f884f 100644
--- a/konversation/src/highlight_preferences.cpp
+++ b/konversation/src/highlight_preferences.cpp
@@ -320,7 +320,7 @@ void Highlight_Config::playSound()
void Highlight_Config::saveSettings()
{
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
// Write all highlight entries
TQPtrList<Highlight> hiList=getHighlightList();
diff --git a/konversation/src/ircview.cpp b/konversation/src/ircview.cpp
index 6ef0530..d7b71da 100644
--- a/konversation/src/ircview.cpp
+++ b/konversation/src/ircview.cpp
@@ -1782,7 +1782,7 @@ void IRCView::saveLinkAs(const TQString& url)
return;
KURL destination = dialog.selectedURL();
- KIO::copyAs(source, destination);
+ TDEIO::copyAs(source, destination);
}
#include "ircview.moc"
diff --git a/konversation/src/konversationapplication.cpp b/konversation/src/konversationapplication.cpp
index de1ecf7..69c7f70 100644
--- a/konversation/src/konversationapplication.cpp
+++ b/konversation/src/konversationapplication.cpp
@@ -274,7 +274,7 @@ void KonversationApplication::dcopInfo(const TQString& string)
void KonversationApplication::readOptions()
{
// get standard config file
- KConfig* config=kapp->config();
+ TDEConfig* config=kapp->config();
// read nickname sorting order for channel nick lists
config->setGroup("Sort Nicknames");
@@ -543,7 +543,7 @@ void KonversationApplication::readOptions()
void KonversationApplication::saveOptions(bool updateGUI)
{
- KConfig* config=kapp->config();
+ TDEConfig* config=kapp->config();
// Should be handled in NicklistBehaviorConfigController now
// config->setGroup("Sort Nicknames");
diff --git a/konversation/src/konvisettingsdialog.cpp b/konversation/src/konvisettingsdialog.cpp
index a5e01f3..7cfccd2 100644
--- a/konversation/src/konvisettingsdialog.cpp
+++ b/konversation/src/konvisettingsdialog.cpp
@@ -241,7 +241,7 @@ void KonviSettingsDialog::showEvent(TQShowEvent* e)
void KonviSettingsDialog::modifiedSlot()
{
- // this is for the non KConfigXT parts to tell us, if the user actually changed
+ // this is for the non TDEConfigXT parts to tell us, if the user actually changed
// something or went back to the old settings
// kdDebug() << "KonviSettingsDialog::modifiedSlot()" << endl;
m_modified = false;
@@ -267,7 +267,7 @@ void KonviSettingsDialog::updateSettings()
TQIntDictIterator<KonviSettingsPage> it( m_indexToPageMapping );
for ( ; it.current(); ++it )
{
- // this is for the non KConfigXT parts to update the UI (like quick buttons)
+ // this is for the non TDEConfigXT parts to update the UI (like quick buttons)
(*it).saveSettings();
}
m_modified = false;
diff --git a/konversation/src/konvisettingspage.h b/konversation/src/konvisettingspage.h
index e7c6aad..6dbeb75 100644
--- a/konversation/src/konvisettingspage.h
+++ b/konversation/src/konvisettingspage.h
@@ -19,7 +19,7 @@ class KonviSettingsPage
virtual void saveSettings() = 0; // function called when the user klicks "Ok" or "Apply"
virtual void loadSettings() = 0; // function called when the user opens the page
- virtual bool hasChanged() = 0; // is to return if any non-KConfigXT settings have changed
+ virtual bool hasChanged() = 0; // is to return if any non-TDEConfigXT settings have changed
};
#endif
diff --git a/konversation/src/logfilereader.cpp b/konversation/src/logfilereader.cpp
index 5e14f64..2196e5f 100644
--- a/konversation/src/logfilereader.cpp
+++ b/konversation/src/logfilereader.cpp
@@ -155,15 +155,15 @@ void LogfileReader::saveLog()
if(!destination.isEmpty())
{
// replace # with %25 to make it URL conforming
- KIO::Job* job=KIO::copy(KURL(fileName.replace("#","%23")),
+ TDEIO::Job* job=TDEIO::copy(KURL(fileName.replace("#","%23")),
KURL(destination),
true);
- connect(job,TQT_SIGNAL(result(KIO::Job*)),this,TQT_SLOT(copyResult(KIO::Job*)));
+ connect(job,TQT_SIGNAL(result(TDEIO::Job*)),this,TQT_SLOT(copyResult(TDEIO::Job*)));
}
}
-void LogfileReader::copyResult(KIO::Job* job)
+void LogfileReader::copyResult(TDEIO::Job* job)
{
if(job->error()) job->showErrorDialog(this);
diff --git a/konversation/src/logfilereader.h b/konversation/src/logfilereader.h
index c835280..5b5ffd8 100644
--- a/konversation/src/logfilereader.h
+++ b/konversation/src/logfilereader.h
@@ -43,7 +43,7 @@ class LogfileReader : public ChatWindow
void clearLog();
void saveLog();
void closeLog();
- void copyResult(KIO::Job* job);
+ void copyResult(TDEIO::Job* job);
protected:
diff --git a/konversation/src/osd_preferences.cpp b/konversation/src/osd_preferences.cpp
index 663750a..7f22e23 100644
--- a/konversation/src/osd_preferences.cpp
+++ b/konversation/src/osd_preferences.cpp
@@ -129,7 +129,7 @@ void OSD_Config::hideEvent(TQHideEvent*)
bool OSD_Config::hasChanged()
{
- // follow the interface, no Non-KConfigXT settings here, so none have changed
+ // follow the interface, no Non-TDEConfigXT settings here, so none have changed
return false;
}
diff --git a/konversation/src/outputfilter.cpp b/konversation/src/outputfilter.cpp
index 2e82a27..aec4e7c 100644
--- a/konversation/src/outputfilter.cpp
+++ b/konversation/src/outputfilter.cpp
@@ -953,7 +953,7 @@ namespace Konversation
return result;
}
- OutputFilterResult OutputFilter::resumeRequest(const TQString &sender,const TQString &fileName,const TQString &port,KIO::filesize_t startAt)
+ OutputFilterResult OutputFilter::resumeRequest(const TQString &sender,const TQString &fileName,const TQString &port,TDEIO::filesize_t startAt)
{
TQString niftyFileName(fileName);
@@ -1127,7 +1127,7 @@ namespace Konversation
TQString password;
bool keep = false;
- int ret = KIO::PasswordDialog::getNameAndPassword
+ int ret = TDEIO::PasswordDialog::getNameAndPassword
(
nick,
password,
@@ -1137,7 +1137,7 @@ namespace Konversation
i18n("IRC Operator Password")
);
- if(ret == KIO::PasswordDialog::Accepted)
+ if(ret == TDEIO::PasswordDialog::Accepted)
{
result.toServer = "OPER " + nick + ' ' + password;
}
diff --git a/konversation/src/outputfilter.h b/konversation/src/outputfilter.h
index 2324a71..63729d6 100644
--- a/konversation/src/outputfilter.h
+++ b/konversation/src/outputfilter.h
@@ -67,7 +67,7 @@ namespace Konversation
OutputFilterResult acceptResumeRequest(const TQString &recipient,const TQString &fileName,const TQString &port,int startAt);
// dcc recv
- OutputFilterResult resumeRequest(const TQString &sender,const TQString &fileName,const TQString &port,KIO::filesize_t startAt);
+ OutputFilterResult resumeRequest(const TQString &sender,const TQString &fileName,const TQString &port,TDEIO::filesize_t startAt);
OutputFilterResult acceptPassiveSendRequest(const TQString& recipient,const TQString &fileName,const TQString &address,const TQString &port,unsigned long size,const TQString &token);
bool replaceAliases(TQString& line);
diff --git a/konversation/src/quickbuttons_preferences.cpp b/konversation/src/quickbuttons_preferences.cpp
index 564e1ee..98f5c39 100644
--- a/konversation/src/quickbuttons_preferences.cpp
+++ b/konversation/src/quickbuttons_preferences.cpp
@@ -81,7 +81,7 @@ void QuickButtons_Config::setButtonsListView(const TQStringList &buttonList)
void QuickButtons_Config::saveSettings()
{
// get configuration object
- KConfig* config=kapp->config();
+ TDEConfig* config=kapp->config();
// delete all buttons
config->deleteGroup("Button List");
@@ -101,7 +101,7 @@ void QuickButtons_Config::saveSettings()
config->writeEntry(TQString("Button%1").arg(index),newList[index]);
} // for
}
- // if there were no buttons at all, write a dummy entry to prevent KConfigXT from "optimizing"
+ // if there were no buttons at all, write a dummy entry to prevent TDEConfigXT from "optimizing"
// the group out, which would in turn make konvi restore the default buttons
else
config->writeEntry("Empty List",TQString());
diff --git a/konversation/src/server.cpp b/konversation/src/server.cpp
index e4fed1c..8fcdc53 100644
--- a/konversation/src/server.cpp
+++ b/konversation/src/server.cpp
@@ -535,7 +535,7 @@ void Server::lookupFinished()
// inform user about the error
getStatusView()->appendServerMessage(i18n("Error"),i18n("Server %1 not found: %2")
.arg(getConnectionSettings().server().host())
- .arg(m_socket->KSocketBase::errorString(m_socket->error())));
+ .arg(m_socket->TDESocketBase::errorString(m_socket->error())));
m_socket->resetStatus();
@@ -608,7 +608,7 @@ void Server::broken(int state)
TQString error = i18n("Connection to Server %1 lost: %2.")
.arg(getConnectionSettings().server().host())
- .arg(KNetwork::KSocketBase::errorString((KNetwork::KSocketBase::SocketError)state));
+ .arg(KNetwork::TDESocketBase::errorString((KNetwork::TDESocketBase::SocketError)state));
getStatusView()->appendServerMessage(i18n("Error"), error);
@@ -908,7 +908,7 @@ void Server::incoming()
{
getStatusView()->appendServerMessage(i18n("Error"),
i18n("There was an error reading the data from the server: %1").
- arg(m_socket->KSocketBase::errorString()));
+ arg(m_socket->TDESocketBase::errorString()));
broken(m_socket->error());
return;
@@ -1711,7 +1711,7 @@ void Server::addDccGet(const TQString &sourceNick, const TQStringList &dccArgume
i18n( "%1 offers to send you \"%2\" (%3)..." )
.arg( newDcc->getPartnerNick(),
showfile,
- ( newDcc->getFileSize() == 0 ) ? i18n( "unknown size" ) : KIO::convertSize( newDcc->getFileSize() ) ) );
+ ( newDcc->getFileSize() == 0 ) ? i18n( "unknown size" ) : TDEIO::convertSize( newDcc->getFileSize() ) ) );
if(Preferences::dccAutoGet())
newDcc->start();
@@ -1742,7 +1742,7 @@ void Server::dccSendRequest(const TQString &partner, const TQString &fileName, c
i18n( "Asking %1 to accept upload of \"%2\" (%3)..." )
.arg( partner,
showfile,
- ( size == 0 ) ? i18n( "unknown size" ) : KIO::convertSize( size ) ) );
+ ( size == 0 ) ? i18n( "unknown size" ) : TDEIO::convertSize( size ) ) );
}
void Server::dccPassiveSendRequest(const TQString& recipient,const TQString& fileName,const TQString& address,unsigned long size,const TQString& token)
@@ -1751,7 +1751,7 @@ void Server::dccPassiveSendRequest(const TQString& recipient,const TQString& fil
queue(result.toServer);
}
-void Server::dccResumeGetRequest(const TQString &sender, const TQString &fileName, const TQString &port, KIO::filesize_t startAt)
+void Server::dccResumeGetRequest(const TQString &sender, const TQString &fileName, const TQString &port, TDEIO::filesize_t startAt)
{
Konversation::OutputFilterResult result;
@@ -1820,7 +1820,7 @@ void Server::resumeDccGetTransfer(const TQString &sourceNick, const TQStringList
.arg( showfile,
sourceNick,
TQString::number( dccTransfer->getProgress() ),
- ( dccTransfer->getFileSize() == 0 ) ? i18n( "unknown size" ) : KIO::convertSize( dccTransfer->getFileSize() ) ) );
+ ( dccTransfer->getFileSize() == 0 ) ? i18n( "unknown size" ) : TDEIO::convertSize( dccTransfer->getFileSize() ) ) );
}
else
{
@@ -1855,7 +1855,7 @@ void Server::resumeDccSendTransfer(const TQString &sourceNick, const TQStringLis
.arg( showfile,
sourceNick,
TQString::number(dccTransfer->getProgress()),
- ( dccTransfer->getFileSize() == 0 ) ? i18n( "unknown size" ) : KIO::convertSize( dccTransfer->getFileSize() ) ) );
+ ( dccTransfer->getFileSize() == 0 ) ? i18n( "unknown size" ) : TDEIO::convertSize( dccTransfer->getFileSize() ) ) );
// FIXME: this operation should be done by DccTransferManager
Konversation::OutputFilterResult result = getOutputFilter()->acceptResumeRequest( sourceNick, fileName, ownPort, position );
@@ -1934,7 +1934,7 @@ void Server::dccStatusChanged(DccTransfer *item, int newStatus, int oldStatus)
appendMessageToFrontmost( i18n( "DCC" ),
i18n( "%1 = file name, %2 = file size, %3 = nickname of sender", "Downloading \"%1\" (%2) from %3...")
.arg( showfile,
- ( item->getFileSize() == 0 ) ? i18n( "unknown size" ) : KIO::convertSize( item->getFileSize() ),
+ ( item->getFileSize() == 0 ) ? i18n( "unknown size" ) : TDEIO::convertSize( item->getFileSize() ),
item->getPartnerNick() ) );
}
}
diff --git a/konversation/src/server.h b/konversation/src/server.h
index 35e9ac2..cefb41d 100644
--- a/konversation/src/server.h
+++ b/konversation/src/server.h
@@ -338,7 +338,7 @@ void resetNickSelection();
void dccSendRequest(const TQString& recipient,const TQString& fileName,const TQString& address,const TQString& port,unsigned long size);
void dccPassiveSendRequest(const TQString& recipient,const TQString& fileName,const TQString& address,unsigned long size,const TQString& token);
// invoked by DccTransferRecv
- void dccResumeGetRequest(const TQString& sender,const TQString& fileName,const TQString& port,KIO::filesize_t startAt);
+ void dccResumeGetRequest(const TQString& sender,const TQString& fileName,const TQString& port,TDEIO::filesize_t startAt);
void dccReverseSendAck(const TQString& partnerNick,const TQString& fileName,const TQString& ownAddress,const TQString& ownPort,unsigned long size,const TQString& reverseToken);
// IRCQueueManager
diff --git a/konversation/src/serverlistdialog.cpp b/konversation/src/serverlistdialog.cpp
index cd37cd1..11cc11a 100644
--- a/konversation/src/serverlistdialog.cpp
+++ b/konversation/src/serverlistdialog.cpp
@@ -162,7 +162,7 @@ namespace Konversation
updateButtons();
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("ServerListDialog");
TQSize newSize = size();
newSize = config->readSizeEntry("Size", &newSize);
@@ -173,7 +173,7 @@ namespace Konversation
ServerListDialog::~ServerListDialog()
{
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("ServerListDialog");
config->writeEntry("Size", size());
}
diff --git a/konversation/src/theme_preferences.cpp b/konversation/src/theme_preferences.cpp
index c2d2d8f..b4099b0 100644
--- a/konversation/src/theme_preferences.cpp
+++ b/konversation/src/theme_preferences.cpp
@@ -145,7 +145,7 @@ void Theme_Config::saveSettings()
if(hasChanged())
{
// save icon theme name
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("Themes");
config->writeEntry("IconTheme",m_currentTheme);
// set in-memory theme to the saved theme
@@ -179,10 +179,10 @@ void Theme_Config::installTheme()
TQString themesDir(locateLocal("data", "konversation/themes/"));
TQString tmpThemeFile;
- if(!KIO::NetAccess::download(themeURL, tmpThemeFile, NULL))
+ if(!TDEIO::NetAccess::download(themeURL, tmpThemeFile, NULL))
{
KMessageBox::error(0L,
- KIO::NetAccess::lastErrorString(),
+ TDEIO::NetAccess::lastErrorString(),
i18n("Failed to Download Theme"),
KMessageBox::Notify
);
@@ -194,7 +194,7 @@ void Theme_Config::installTheme()
if(themeInstallDir.exists()) // We got a directory not a file
{
if(themeInstallDir.exists("index.desktop"))
- KIO::NetAccess::dircopy(KURL(tmpThemeFile),KURL(themesDir),0L);
+ TDEIO::NetAccess::dircopy(KURL(tmpThemeFile),KURL(themesDir),0L);
else
{
KMessageBox::error(0L,
@@ -233,7 +233,7 @@ void Theme_Config::installTheme()
}
loadSettings();
- KIO::NetAccess::removeTempFile(tmpThemeFile);
+ TDEIO::NetAccess::removeTempFile(tmpThemeFile);
}
@@ -254,12 +254,12 @@ void Theme_Config::removeTheme()
if(remove == KMessageBox::Continue)
{
unlink(TQFile::encodeName(dir));
- KIO::DeleteJob* job = KIO::del(KURL(dir.remove("index.desktop")));
- connect(job, TQT_SIGNAL(result(KIO::Job*)), this, TQT_SLOT(postRemoveTheme(KIO::Job*)));
+ TDEIO::DeleteJob* job = TDEIO::del(KURL(dir.remove("index.desktop")));
+ connect(job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(postRemoveTheme(TDEIO::Job*)));
}
}
-void Theme_Config::postRemoveTheme(KIO::Job* /* delete_job */)
+void Theme_Config::postRemoveTheme(TDEIO::Job* /* delete_job */)
{
loadSettings();
}
diff --git a/konversation/src/theme_preferences.h b/konversation/src/theme_preferences.h
index 28e124f..e28a018 100644
--- a/konversation/src/theme_preferences.h
+++ b/konversation/src/theme_preferences.h
@@ -46,7 +46,7 @@ class Theme_Config : public Theme_ConfigUI, public KonviSettingsPage
void updateButtons();
void installTheme();
void removeTheme();
- void postRemoveTheme(KIO::Job* delete_job);
+ void postRemoveTheme(TDEIO::Job* delete_job);
private:
TQStringList m_dirs;
diff --git a/konversation/src/warnings_preferences.cpp b/konversation/src/warnings_preferences.cpp
index e8d62b7..70f5428 100644
--- a/konversation/src/warnings_preferences.cpp
+++ b/konversation/src/warnings_preferences.cpp
@@ -56,7 +56,7 @@ void Warnings_Config::restorePageToDefaults()
void Warnings_Config::saveSettings()
{
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("Notification Messages");
// prepare list
@@ -122,7 +122,7 @@ void Warnings_Config::loadSettings()
TQCheckListItem *item;
dialogListView->clear();
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("Notification Messages");
TQString flagName;
for(unsigned int i=0; i<dialogDefinitions.count() ;i++)
diff --git a/konversation/src/dcctransferrecv.h b/konversation/src/dcctransferrecv.h
index 92f4201..ceb6fde 100644
--- a/konversation/src/dcctransferrecv.h
+++ b/konversation/src/dcctransferrecv.h
@@ -27,7 +27,7 @@
class TQFile;
class TQTimer;
-namespace KIO
+namespace TDEIO
{
class Job;
class TransferJob;
@@ -35,7 +35,7 @@ namespace KIO
namespace KNetwork
{
- class KServerSocket;
+ class TDEServerSocket;
class KStreamSocket;
}
@@ -82,9 +82,9 @@ class DccTransferRecv : public DccTransfer
protected slots:
// Local KIO
- void slotLocalCanResume( KIO::Job* job, KIO::filesize_t size );
- void slotLocalGotResult( KIO::Job* job );
- void slotLocalReady( KIO::Job* job );
+ void slotLocalCanResume( TDEIO::Job* job, TDEIO::filesize_t size );
+ void slotLocalGotResult( TDEIO::Job* job );
+ void slotLocalReady( TDEIO::Job* job );
void slotLocalWriteDone();
void slotLocalGotWriteError( const TQString& errorString );
@@ -106,11 +106,11 @@ class DccTransferRecv : public DccTransfer
void failed(const TQString& errorMessage = TQString() );
// (startPosition == 0) means "don't resume"
- void prepareLocalKio( bool overwrite, bool resume, KIO::fileoffset_t startPosition = 0 );
- void askAndPrepareLocalKio( const TQString& message, int enabledActions, DccResumeDialog::ReceiveAction defaultAction, KIO::fileoffset_t startPosition = 0 );
+ void prepareLocalKio( bool overwrite, bool resume, TDEIO::fileoffset_t startPosition = 0 );
+ void askAndPrepareLocalKio( const TQString& message, int enabledActions, DccResumeDialog::ReceiveAction defaultAction, TDEIO::fileoffset_t startPosition = 0 );
/**
* This calls KIO::NetAccess::mkdir on all the subdirectories of dirURL, to
* create the given directory. Note that a url like file:/foo/bar will
* make sure both foo and bar are created. It assumes everything in the path is
* a directory.
@@ -133,15 +133,15 @@ class DccTransferRecv : public DccTransfer
protected:
KURL m_saveToTmpFileURL;
///Current filesize of the file saved on the disk.
- KIO::filesize_t m_saveToFileSize;
+ TDEIO::filesize_t m_saveToFileSize;
///Current filesize of the file+".part" saved on the disk.
- KIO::filesize_t m_partialFileSize;
+ TDEIO::filesize_t m_partialFileSize;
DccTransferRecvWriteCacheHandler* m_writeCacheHandler;
bool m_saveToFileExists;
bool m_partialFileExists;
TQTimer* m_connectionTimer;
- KNetwork::KServerSocket* m_serverSocket;
+ KNetwork::TDEServerSocket* m_serverSocket;
KNetwork::KStreamSocket* m_recvSocket;
private:
@@ -155,7 +155,7 @@ class DccTransferRecvWriteCacheHandler : public TQObject
public:
- explicit DccTransferRecvWriteCacheHandler( KIO::TransferJob* transferJob );
+ explicit DccTransferRecvWriteCacheHandler( TDEIO::TransferJob* transferJob );
virtual ~DccTransferRecvWriteCacheHandler();
void append( char* data, int size );
@@ -171,11 +171,11 @@ class DccTransferRecvWriteCacheHandler : public TQObject
protected slots:
// <- m_transferJob->dataReq()
- void slotKIODataReq( KIO::Job* job, TQByteArray& data );
- void slotKIOResult( KIO::Job* job ); // <- m_transferJob->result()
+ void slotKIODataReq( TDEIO::Job* job, TQByteArray& data );
+ void slotKIOResult( TDEIO::Job* job ); // <- m_transferJob->result()
protected:
- KIO::TransferJob* m_transferJob;
+ TDEIO::TransferJob* m_transferJob;
bool m_writeAsyncMode;
bool m_writeReady;
@@ -106,11 +106,11 @@ class DccTransferRecv : public DccTransfer
/**
- * This calls KIO::NetAccess::mkdir on all the subdirectories of dirURL, to
+ * This calls TDEIO::NetAccess::mkdir on all the subdirectories of dirURL, to
* create the given directory. Note that a url like file:/foo/bar will
* make sure both foo and bar are created. It assumes everything in the path is
diff --git a/konversation/src/dcctransfersend.cpp b/konversation/src/dcctransfersend.cpp
index 7a13570..2e4b417 100644
--- a/konversation/src/dcctransfersend.cpp
+++ b/konversation/src/dcctransfersend.cpp
@@ -73,7 +73,7 @@ void DccTransferSend::cleanUp()
stopConnectionTimer();
finishTransferLogger();
if ( !m_tmpFile.isEmpty() )
- KIO::NetAccess::removeTempFile( m_tmpFile );
+ TDEIO::NetAccess::removeTempFile( m_tmpFile );
m_tmpFile = TQString();
m_file.close();
if ( m_sendSocket )
@@ -114,7 +114,7 @@ void DccTransferSend::setOwnIp( const TQString& ownIp )
m_ownIp = ownIp;
}
-void DccTransferSend::setFileSize( KIO::filesize_t fileSize )
+void DccTransferSend::setFileSize( TDEIO::filesize_t fileSize )
{
if ( getStatus() == Configuring )
m_fileSize = fileSize;
@@ -168,18 +168,18 @@ bool DccTransferSend::queue()
kdDebug() << "DccTransferSend::DccTransferSend(): Fast DCC send: " << m_fastSend << endl;
//Check the file exists
- if ( !KIO::NetAccess::exists( m_fileURL, true, NULL ) )
+ if ( !TDEIO::NetAccess::exists( m_fileURL, true, NULL ) )
{
failed( i18n( "The url \"%1\" does not exist" ).arg( m_fileURL.prettyURL() ) );
return false;
}
//FIXME: KIO::NetAccess::download() is a synchronous function. we should use KIO::get() instead.
//Download the file. Does nothing if it's local (file:/)
- if ( !KIO::NetAccess::download( m_fileURL, m_tmpFile, NULL ) )
+ if ( !TDEIO::NetAccess::download( m_fileURL, m_tmpFile, NULL ) )
{
failed( i18n( "Could not retrieve \"%1\"" ).arg( m_fileURL.prettyURL() ) );
- kdDebug() << "DccTransferSend::DccTransferSend(): KIO::NetAccess::download() failed. reason: " << KIO::NetAccess::lastErrorString() << endl;
+ kdDebug() << "DccTransferSend::DccTransferSend(): TDEIO::NetAccess::download() failed. reason: " << TDEIO::NetAccess::lastErrorString() << endl;
return false;
}
@@ -381,9 +381,9 @@ void DccTransferSend::writeData() // slot
{
m_sendSocket->writeBlock( m_buffer, actual );
m_transferringPosition += actual;
- if ( (KIO::fileoffset_t)m_fileSize <= m_transferringPosition )
+ if ( (TDEIO::fileoffset_t)m_fileSize <= m_transferringPosition )
{
- Q_ASSERT( (KIO::fileoffset_t)m_fileSize == m_transferringPosition );
+ Q_ASSERT( (TDEIO::fileoffset_t)m_fileSize == m_transferringPosition );
kdDebug() << "DccTransferSend::writeData(): Done." << endl;
m_sendSocket->enableWrite( false ); // there is no need to call this function anymore
}
@@ -393,7 +393,7 @@ void DccTransferSend::writeData() // slot
void DccTransferSend::getAck() // slot
{
//kdDebug() << "DccTransferSend::getAck()" << endl;
- if ( !m_fastSend && m_transferringPosition < (KIO::fileoffset_t)m_fileSize )
+ if ( !m_fastSend && m_transferringPosition < (TDEIO::fileoffset_t)m_fileSize )
{
m_sendSocket->enableWrite( true );
m_sendSocket->enableRead( false );
@@ -445,7 +445,7 @@ void DccTransferSend::slotConnectionTimeout() // slot
void DccTransferSend::slotConnectionFailed( int /* errorCode */ )
{
- failed( i18n( "Connection failure: %1" ).arg( m_sendSocket->KSocketBase::errorString() ) );
+ failed( i18n( "Connection failure: %1" ).arg( m_sendSocket->TDESocketBase::errorString() ) );
}
void DccTransferSend::slotServerSocketClosed()
@@ -457,7 +457,7 @@ void DccTransferSend::slotSendSocketClosed()
{
kdDebug() << "DccTransferSend::slotSendSocketClosed()" << endl;
finishTransferLogger();
- if ( getStatus() == Transferring && m_transferringPosition < (KIO::fileoffset_t)m_fileSize )
+ if ( getStatus() == Transferring && m_transferringPosition < (TDEIO::fileoffset_t)m_fileSize )
failed( i18n( "Remote user disconnected" ) );
}
@@ -168,18 +168,18 @@ bool DccTransferSend::queue()
return false;
}
- //FIXME: KIO::NetAccess::download() is a synchronous function. we should use KIO::get() instead.
+ //FIXME: TDEIO::NetAccess::download() is a synchronous function. we should use TDEIO::get() instead.
//Download the file. Does nothing if it's local (file:/)
diff --git a/konversation/src/konviconfigdialog.cpp b/konversation/src/konviconfigdialog.cpp
index 2e5050f..4610144 100644
--- a/konversation/src/konviconfigdialog.cpp
+++ b/konversation/src/konviconfigdialog.cpp
@@ -21,18 +21,18 @@
*/
/*
* KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
* Differences from KConfigDialog:
* - Use TQStringList instead of TQString for the item name(s) in addPage and
* addPageInternal, thus calling the respective KDialogBase methods which
* allow specifying a path from which the TreeList hierarchy is constructed.
* - Use 16x16 icons in the TreeList.
* - Fill a new int m_lastAddedIndex with the pageIndex() of a new page added
* with addPageInternal, and offer a public interface int lastAddedIndex().
* See the KConfigDialog reference for detailed documentation.
*
* begin: Nov 22 2005
- * copyright: (C) 2005-2006 by Eike Hein, KConfigDialog developers
+ * copyright: (C) 2005-2006 by Eike Hein, TDEConfigDialog developers
* email: hein@kde.org
*/
@@ -52,26 +52,26 @@
TQAsciiDict<KonviConfigDialog> KonviConfigDialog::openDialogs;
// This class is here purly so we don't break binary compatibility down the road.
-class KonviConfigDialog::KConfigDialogPrivate
+class KonviConfigDialog::TDEConfigDialogPrivate
{
public:
- KConfigDialogPrivate(KDialogBase::DialogType t) : shown(false), type(t), manager(0) { }
+ TDEConfigDialogPrivate(KDialogBase::DialogType t) : shown(false), type(t), manager(0) { }
bool shown;
KDialogBase::DialogType type;
- KConfigDialogManager *manager;
- TQMap<TQWidget *, KConfigDialogManager *> managerForPage;
+ TDEConfigDialogManager *manager;
+ TQMap<TQWidget *, TDEConfigDialogManager *> managerForPage;
};
KonviConfigDialog::KonviConfigDialog( TQWidget *parent, const char *name,
- KConfigSkeleton *config,
+ TDEConfigSkeleton *config,
DialogType dialogType,
int dialogButtons,
ButtonCode defaultButton,
bool modal ) :
KDialogBase( dialogType, TQt::WStyle_DialogBorder,
parent, name, modal, i18n("Configure"), dialogButtons, defaultButton ),
- d(new KConfigDialogPrivate(dialogType))
+ d(new TDEConfigDialogPrivate(dialogType))
{
if ( name )
{
@@ -91,7 +91,7 @@ KonviConfigDialog::KonviConfigDialog( TQWidget *parent, const char *name,
connect(this, TQT_SIGNAL(defaultClicked()), this, TQT_SLOT(updateWidgetsDefault()));
connect(this, TQT_SIGNAL(defaultClicked()), this, TQT_SLOT(updateButtons()));
- d->manager = new KConfigDialogManager(this, config);
+ d->manager = new TDEConfigDialogManager(this, config);
setupManagerConnections(d->manager);
enableButton(Apply, false);
@@ -115,13 +115,13 @@ void KonviConfigDialog::addPage(TQWidget *page,
}
void KonviConfigDialog::addPage(TQWidget *page,
- KConfigSkeleton *config,
+ TDEConfigSkeleton *config,
const TQStringList &items,
const TQString &pixmapName,
const TQString &header)
{
addPageInternal(page, items, pixmapName, header);
- d->managerForPage[page] = new KConfigDialogManager(page, config);
+ d->managerForPage[page] = new TDEConfigDialogManager(page, config);
setupManagerConnections(d->managerForPage[page]);
}
@@ -170,7 +170,7 @@ void KonviConfigDialog::addPageInternal(TQWidget *page,
}
}
-void KonviConfigDialog::setupManagerConnections(KConfigDialogManager *manager)
+void KonviConfigDialog::setupManagerConnections(TDEConfigDialogManager *manager)
{
connect(manager, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(settingsChangedSlot()));
connect(manager, TQT_SIGNAL(widgetModified()), this, TQT_SLOT(updateButtons()));
@@ -199,7 +199,7 @@ void KonviConfigDialog::updateButtons()
if (only_once) return;
only_once = true;
- TQMap<TQWidget *, KConfigDialogManager *>::iterator it;
+ TQMap<TQWidget *, TDEConfigDialogManager *>::iterator it;
bool has_changed = d->manager->hasChanged() || hasChanged();
for (it = d->managerForPage.begin();
@@ -235,7 +235,7 @@ void KonviConfigDialog::settingsChangedSlot()
void KonviConfigDialog::show()
{
- TQMap<TQWidget *, KConfigDialogManager *>::iterator it;
+ TQMap<TQWidget *, TDEConfigDialogManager *>::iterator it;
updateWidgets();
d->manager->updateWidgets();
@@ -21,18 +21,18 @@
*/
/*
- * KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
- * Differences from KConfigDialog:
+ * TDEConfigDialog derivative allowing for a multi-level hierarchical TreeList.
+ * Differences from TDEConfigDialog:
* - Use TQStringList instead of TQString for the item name(s) in addPage and
* addPageInternal, thus calling the respective KDialogBase methods which
@@ -21,18 +21,18 @@
* - Fill a new int m_lastAddedIndex with the pageIndex() of a new page added
* with addPageInternal, and offer a public interface int lastAddedIndex().
- * See the KConfigDialog reference for detailed documentation.
+ * See the TDEConfigDialog reference for detailed documentation.
*
* begin: Nov 22 2005
diff --git a/konversation/src/konviconfigdialog.h b/konversation/src/konviconfigdialog.h
index 6a7365c..9068eea 100644
--- a/konversation/src/konviconfigdialog.h
+++ b/konversation/src/konviconfigdialog.h
@@ -21,18 +21,18 @@
*/
/*
* KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
* Differences from KConfigDialog:
* - Use TQStringList instead of TQString for the item name(s) in addPage and
* addPageInternal, thus calling the respective KDialogBase methods which
* allow specifying a path from which the TreeList hierarchy is constructed.
* - Use 16x16 icons in the TreeList.
* - Fill a new int m_lastAddedIndex with the pageIndex() of a new page added
* with addPageInternal, and offer a public interface int lastAddedIndex().
* See the KConfigDialog reference for detailed documentation.
*
* begin: Nov 22 2005
- * copyright: (C) 2005-2006 by Eike Hein, KConfigDialog developers
+ * copyright: (C) 2005-2006 by Eike Hein, TDEConfigDialog developers
* email: hein@kde.org
*/
@@ -44,9 +44,9 @@
#include <kdialogbase.h>
-class KConfig;
-class KConfigSkeleton;
-class KConfigDialogManager;
+class TDEConfig;
+class TDEConfigSkeleton;
+class TDEConfigDialogManager;
class KonviConfigDialog : public KDialogBase
{
@@ -64,7 +64,7 @@ class KonviConfigDialog : public KDialogBase
public:
KonviConfigDialog( TQWidget *parent, const char *name,
- KConfigSkeleton *config,
+ TDEConfigSkeleton *config,
DialogType dialogType = IconList,
int dialogButtons = Default|Ok|Apply|Cancel|Help,
ButtonCode defaultButton = Ok,
@@ -77,7 +77,7 @@ class KonviConfigDialog : public KDialogBase
const TQString &header=TQString(),
bool manage=true );
- void addPage( TQWidget *page, KConfigSkeleton *config,
+ void addPage( TQWidget *page, TDEConfigSkeleton *config,
const TQStringList &items,
const TQString &pixmapName,
const TQString &header=TQString() );
@@ -111,14 +111,14 @@ class KonviConfigDialog : public KDialogBase
void addPageInternal(TQWidget *page, const TQStringList &items,
const TQString &pixmapName, const TQString &header);
- void setupManagerConnections(KConfigDialogManager *manager);
+ void setupManagerConnections(TDEConfigDialogManager *manager);
private:
static TQAsciiDict<KonviConfigDialog> openDialogs;
- class KConfigDialogPrivate;
+ class TDEConfigDialogPrivate;
- KConfigDialogPrivate *d;
+ TDEConfigDialogPrivate *d;
int m_lastAddedIndex;
};
@@ -21,18 +21,18 @@
*/
/*
- * KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
- * Differences from KConfigDialog:
+ * TDEConfigDialog derivative allowing for a multi-level hierarchical TreeList.
+ * Differences from TDEConfigDialog:
* - Use TQStringList instead of TQString for the item name(s) in addPage and
* addPageInternal, thus calling the respective KDialogBase methods which
@@ -21,18 +21,18 @@
* - Fill a new int m_lastAddedIndex with the pageIndex() of a new page added
* with addPageInternal, and offer a public interface int lastAddedIndex().
- * See the KConfigDialog reference for detailed documentation.
+ * See the TDEConfigDialog reference for detailed documentation.
*
* begin: Nov 22 2005